.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.component.modelinterface
-------------------------------------

.. automodule:: reahl.component.modelinterface


Fields
^^^^^^

FieldIndex
""""""""""

.. autoclass:: FieldIndex
   :members:

ExposedDecorator
""""""""""""""""

.. autoclass:: ExposedDecorator
   :members:


Field
"""""

.. autoclass:: Field
   :members:

CurrentUser
"""""""""""

.. autoclass:: CurrentUser
   :members:

EmailField
""""""""""

.. autoclass:: EmailField
   :members:

PasswordField
"""""""""""""

.. autoclass:: PasswordField
   :members:
   
BooleanField
""""""""""""

.. autoclass:: BooleanField
   :members:

IntegerField
""""""""""""

.. autoclass:: IntegerField
   :members:

DateField
"""""""""

.. autoclass:: DateField
   :members:


Inputting predefined values
^^^^^^^^^^^^^^^^^^^^^^^^^^^

ChoiceField
"""""""""""

.. autoclass:: ChoiceField
   :members:

MultiChoiceField
""""""""""""""""

.. autoclass:: MultiChoiceField
   :members:

Choice
""""""

.. autoclass:: Choice
   :members:

ChoiceGroup
"""""""""""

.. autoclass:: ChoiceGroup
   :members:

Inputting files
^^^^^^^^^^^^^^^

FileField
"""""""""

.. autoclass:: FileField
   :members:

UploadedFile
""""""""""""

.. autoclass:: UploadedFile
   :members:
   
Constraints
^^^^^^^^^^^

ValidationConstraint
""""""""""""""""""""

.. autoclass:: ValidationConstraint
   :members:
   
RemoteConstraint
""""""""""""""""

.. autoclass:: RemoteConstraint
   :members:

RequiredConstraint
""""""""""""""""""

.. autoclass:: RequiredConstraint
   :members:

EqualToConstraint
"""""""""""""""""

.. autoclass:: EqualToConstraint
   :members:

GreaterThanConstraint
"""""""""""""""""""""

.. autoclass:: GreaterThanConstraint
   :members:

SmallerThanConstraint
"""""""""""""""""""""

.. autoclass:: SmallerThanConstraint
   :members:

MinLengthConstraint
"""""""""""""""""""

.. autoclass:: MinLengthConstraint
   :members:

MaxLengthConstraint
"""""""""""""""""""

.. autoclass:: MaxLengthConstraint
   :members:

PatternConstraint
"""""""""""""""""

.. autoclass:: PatternConstraint
   :members:

AllowedValuesConstraint
"""""""""""""""""""""""

.. autoclass:: AllowedValuesConstraint
   :members:

IntegerConstraint
"""""""""""""""""

.. autoclass:: IntegerConstraint
   :members:

MinValueConstraint
""""""""""""""""""

.. autoclass:: MinValueConstraint
   :members:

MaxValueConstraint
""""""""""""""""""

.. autoclass:: MaxValueConstraint
   :members:


Events and Actions
^^^^^^^^^^^^^^^^^^

Event
"""""

.. autoclass:: Event
   :members:

Action
""""""

.. autoclass:: Action
   :members:

Allowed
"""""""

.. autoclass:: Allowed
   :members:

Not
"""

.. autoclass:: Not
   :members:


SecuredDeclaration
""""""""""""""""""

.. autoclass:: SecuredDeclaration
   :members:

